Sometimes some ethernet aliases do not exist in U-Boot FDT but they
exist in the FDT used to boot the system. In this situation
setup_environment is called again in ft_board_setup to generate macaddr
environment variable for them. However now the call to
fdt_fixup_ethernet is moved before the call of ft_board_setup.

Call fdt_fixup_ethernet again to add MAC addresses for the extra
ethernet aliases.

Signed-off-by: Icenowy Zheng <icen...@aosc.io>
---
 board/sunxi/board.c | 6 ++++--
 1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/board/sunxi/board.c b/board/sunxi/board.c
index 6e13ee32c1..616a5f77f0 100644
--- a/board/sunxi/board.c
+++ b/board/sunxi/board.c
@@ -745,10 +745,12 @@ int ft_board_setup(void *blob, bd_t *bd)
        int __maybe_unused r;
 
        /*
         * Call setup_environment again in case the boot fdt has
         * ethernet aliases the u-boot copy does not have.
         */
        setup_environment(blob);
+       fdt_fixup_ethernet(blob);
 
 #ifdef CONFIG_VIDEO_DT_SIMPLEFB
        r = sunxi_simplefb_setup(blob);
@@ -745,10 +745,12 @@ int ft_board_setup(void *blob, bd_t *bd)
 
        /*
-        * Call setup_environment again in case the boot fdt has
-        * ethernet aliases the u-boot copy does not have.
+        * Call setup_environment and fdt_fixup_ethernet again
+        * in case the boot fdt has ethernet aliases the u-boot
+        * copy does not have.
         */
        setup_environment(blob);
-- 
2.13.6

_______________________________________________
U-Boot mailing list
U-Boot@lists.denx.de
https://lists.denx.de/listinfo/u-boot

Reply via email to